==> domd-2.1.10.tar.gz: domd-2.1.10/src/domd/core/parsers/ansible_playbook.py <==
"""Parser for Ansible playbook files."""

from pathlib import Path
from typing import TYPE_CHECKING, List

import yaml

from .base import BaseParser

if TYPE_CHECKING:
    from ..commands import Command


class AnsiblePlaybookParser(BaseParser):
    """Parser for Ansible playbook files."""

    @property
    def supported_file_patterns(self) -> List[str]:
        """Return supported file patterns for Ansible playbooks."""
        return [
            "**/playbooks/*.yml",
            "**/playbooks/*.yaml",
            "**/*playbook*.yml",
            "**/*playbook*.yaml",
            "site.yml",
            "site.yaml",
        ]

    @classmethod
    def can_parse(cls, file_path: Path) -> bool:
        """Check if the file is an Ansible playbook."""
        if not file_path.suffix.lower() in [".yml", ".yaml"]:
            return False

        try:
            with open(file_path, "r") as f:
                content = yaml.safe_load(f)
                # Check if it looks like an Ansible playbook
                if isinstance(content, list) and content and "hosts" in content[0]:
                    return True
        except (yaml.YAMLError, UnicodeDecodeError):
            pass

        return False

    def parse(self, content: str = None) -> "List[Command]":
        """Parse Ansible playbook and extract commands.

        Args:
            content: Optional content of the file to parse. If not provided, will read from file_path.

        Returns:
            List of Command objects
        """
        from domd.core.commands import Command

        if not self.file_path or not self.file_path.exists():
            return []

        self._commands: List[Command] = []
        
        # If content is not provided, read from file
        if content is None and not self.file_path.is_dir():
            try:
                with open(self.file_path, 'r', encoding='utf-8') as f:
                    content = f.read()
            except (IOError, UnicodeDecodeError):
                # If we can't read the file, return empty list
                return []
        
        try:
            playbook = yaml.safe_load(content)

            if not isinstance(playbook, list):
                return []

            for play in playbook:
                if not isinstance(play, dict):
                    continue

                play_name = play.get("name", "Unnamed play")
                hosts = play.get("hosts", "all")

                # Create a command to run this playbook
                cmd = (
                    f"ansible-playbook {self.file_path.relative_to(self.project_root)}"
                )
                description = f"Ansible playbook: {play_name} (hosts: {hosts})"

                self._commands.append(
                    Command(
                        command=cmd,
                        description=description,
                        type="ansible_playbook",
                        source=str(self.file_path),
                        metadata={
                            "play_name": play_name,
                            "hosts": hosts,
                            "file": str(self.file_path.relative_to(self.project_root)),
                        },
                    )
                )

        except (yaml.YAMLError, UnicodeDecodeError) as e:
            print(f"Error parsing {self.file_path}: {e}")
            return []

        return self._commands

==> domd-2.2.9.tar.gz: domd-2.2.9/src/domd/core/parsers/ansible_playbook.py <==
"""Parser for Ansible playbook files."""

from pathlib import Path
from typing import TYPE_CHECKING, List

import yaml

from .base import BaseParser

if TYPE_CHECKING:
    from ..commands import Command


class AnsiblePlaybookParser(BaseParser):
    """Parser for Ansible playbook files."""

    @property
    def supported_file_patterns(self) -> List[str]:
        """Return supported file patterns for Ansible playbooks."""
        return [
            "**/playbooks/*.yml",
            "**/playbooks/*.yaml",
            "**/*playbook*.yml",
            "**/*playbook*.yaml",
            "site.yml",
            "site.yaml",
        ]

    @classmethod
    def can_parse(cls, file_path: Path) -> bool:
        """Check if the file is an Ansible playbook."""
        if not file_path.suffix.lower() in [".yml", ".yaml"]:
            return False

        try:
            with open(file_path, "r") as f:
                content = yaml.safe_load(f)
                # Check if it looks like an Ansible playbook
                if isinstance(content, list) and content and "hosts" in content[0]:
                    return True
        except (yaml.YAMLError, UnicodeDecodeError):
            pass

        return False

    def parse(self, content: str = None) -> "List[Command]":
        """Parse Ansible playbook and extract commands.

        Args:
            content: Optional content of the file to parse. If not provided, will read from file_path.

        Returns:
            List of Command objects
        """
        from domd.core.commands import Command

        if not self.file_path or not self.file_path.exists():
            return []

        self._commands: List[Command] = []

        # If content is not provided, read from file
        if content is None and not self.file_path.is_dir():
            try:
                with open(self.file_path, "r", encoding="utf-8") as f:
                    content = f.read()
            except (IOError, UnicodeDecodeError):
                # If we can't read the file, return empty list
                return []

        try:
            playbook = yaml.safe_load(content)

            if not isinstance(playbook, list):
                return []

            # Get relative path if file is in project directory, otherwise use full path
            try:
                playbook_path = self.file_path.relative_to(self.project_root)
            except ValueError:
                playbook_path = self.file_path

            for play in playbook:
                if not isinstance(play, dict):
                    continue

                play_name = play.get("name", "Unnamed play")
                hosts = play.get("hosts", "all")

                # Create a command to run this playbook
                cmd = f"ansible-playbook {playbook_path}"
                description = f"Ansible playbook: {play_name} (hosts: {hosts})"

                self._commands.append(
                    Command(
                        command=cmd,
                        description=description,
                        type="ansible_playbook",
                        source=str(self.file_path),
                        metadata={
                            "play_name": play_name,
                            "hosts": hosts,
                            "file": str(self.file_path.relative_to(self.project_root)),
                        },
                    )
                )

        except (yaml.YAMLError, UnicodeDecodeError) as e:
            print(f"Error parsing {self.file_path}: {e}")
            return []

        return self._commands
